==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/texts/group_setup_rules.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th November 2004 (tom@barnraiser.org)


//BODY TEXT
$lang['txt_group_setup_rules'] = 				"You can find a full introduction about groups, policy and structure within our support area.<br /><p>1. I agree that I will observe the laws of Sweden.<br />2. As part of that I am aware of the BBS act(1998:112) and how I must comply with it within 24 hours otherwise my group will be removed prior to compliance.</p>";

$lang['txt_group_hidden_rules'] = 				"These are the rules for hidden groups.";
$lang['txt_group_visible_rules'] = 				"These are the rules for visible groups.";

?>

==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/texts/group_setup_rules.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th November 2004 (tom@barnraiser.org)


//BODY TEXT
$lang['txt_group_setup_rules'] = 				"You can find a full introduction about groups, policy and structure within our support area.<br /><p>1. I agree that I will observe the laws of Sweden.<br />2. As part of that I am aware of the BBS act(1998:112) and how I must comply with it within 24 hours otherwise my group will be removed prior to compliance.</p>";
$lang['txt_group_hidden_rules'] = 				"These are the rules for hidden groups.";
$lang['txt_group_visible_rules'] = 				"These are the rules for visible groups.";

?>
